@@ -22,9 +22,11 @@ from typing import Generator, Iterable, List, Dict, Any
 
 LOGGER = logging.getLogger('SRVLOG')
 
-_ProviderItem = namedtuple('_ProviderItem', ('provider','exposed'))
+_ProviderItem = namedtuple('_ProviderItem', ('provider', 'exposed'))
 
-def _register_provider(reg: 'QgsProcessingRegistry', provider_id: str, providers: List[_ProviderItem] ) -> None:   # noqa: F821
+
+def _register_provider(reg: 'QgsProcessingRegistry', provider_id: str,  # noqa: F821
+                       providers: List[_ProviderItem]) -> None:
     """ Register scripts provider for exposition
     """
     p = reg.providerById(provider_id)
@@ -33,7 +35,7 @@ def _register_provider(reg: 'QgsProcessingRegistry', provider_id: str, providers
         return
 
     LOGGER.debug("= Registering provider '%s'", provider_id)
-    providers.append(_ProviderItem(p,True))
+    providers.append(_ProviderItem(p, True))
 
 
 class WPSServerInterfaceImpl:
@@ -41,14 +43,14 @@ class WPSServerInterfaceImpl:
     def __init__(self, with_providers: List[str]) -> None:
         self._plugins = {}
         self._paths = []
-        self._providers      = None
+        self._providers = None
         self._with_providers = with_providers
 
     def initialize(self, path: str) -> None:
         """  Collect wps plugins
         """
         path = Path(path)
-        plugins = { p:None for p in find_plugins(path) }
+        plugins = {p: None for p in find_plugins(path)}
         if not plugins:
             LOGGER.warning("No WPS plugin found in %s", path)
         else:
@@ -58,7 +60,7 @@ class WPSServerInterfaceImpl:
         load_styles(path)
 
     @property
-    def plugins(self) -> Dict[str,Any]:
+    def plugins(self) -> Dict[str, Any]:
         return self._plugins
 
     def register_providers(self) -> None:
@@ -72,18 +74,18 @@ class WPSServerInterfaceImpl:
 
         providers = []
         self._providers = providers
-   
+
         # Register internal/default qgis providers
         for provider_id in self._with_providers:
             _register_provider(reg, provider_id, providers)
 
         class _WPSServerInterface:
-            def registerProvider( self, provider: 'QgsAlgorithmProvider', expose: bool = True ) -> None:   # noqa: F821
+            def registerProvider(self, provider: 'QgsAlgorithmProvider', expose: bool = True) -> None:   # noqa: F821
                 reg.addProvider(provider)
                 # IMPORTANT: the processingRegistry does not gain ownership and
-                # the caller must prevent garbage collection by keeping the ownership of 
+                # the caller must prevent garbage collection by keeping the ownership of
                 # the returned instances
-                providers.append(_ProviderItem(provider,expose))
+                providers.append(_ProviderItem(provider, expose))
 
         wpsIface = _WPSServerInterface()
 
@@ -92,10 +94,10 @@ class WPSServerInterfaceImpl:
         for plugin in self._plugins:
             try:
                 __import__(plugin)
-                package = sys.modules[plugin] 
+                package = sys.modules[plugin]
 
                 # Initialize the plugin
-                LOGGER.info("Loaded plugin '%s'",plugin)
+                LOGGER.info("Loaded plugin '%s'", plugin)
                 self._plugins[plugin] = package.WPSClassFactory(wpsIface)
 
                 # Load style from plugin packeges directory
@@ -105,10 +107,10 @@ class WPSServerInterfaceImpl:
                 traceback.print_exc()
 
     @property
-    def providers(self, exposed: bool=True) -> Iterable['QgsAlgorithmProvider']:  # noqa: F821
+    def providers(self, exposed: bool = True) -> Iterable['QgsAlgorithmProvider']:  # noqa: F821
         """ Return loaded  providers
 
-            If exposed is True then return only exposed providers 
+            If exposed is True then return only exposed providers
         """
         if exposed:
             return (p.provider for p in self._providers if p.exposed)
@@ -123,22 +125,22 @@ def checkQgisVersion(minver: str, maxver: str) -> bool:
         major, *ver = ver.split('.')
         major = int(major)
         minor = int(ver[0]) if len(ver) > 0 else 0
-        rev   = int(ver[1]) if len(ver) > 1 else 0
+        rev = int(ver[1]) if len(ver) > 1 else 0
         if minor >= 99:
             minor = rev = 0
             major += 1
         if rev > 99:
             rev = 99
-        return int("{:d}{:02d}{:02d}".format(major,minor,rev))
+        return int("{:d}{:02d}{:02d}".format(major, minor, rev))
 
     version = to_int(Qgis.QGIS_VERSION.split('-')[0])
-    minver  = to_int(minver) if minver else version
-    maxver  = to_int(maxver) if maxver else version
+    minver = to_int(minver) if minver else version
+    maxver = to_int(maxver) if maxver else version
 
     return minver <= version <= maxver
 
-    
-def find_plugins(path: Path) -> Generator[str,None,None]:
+
+def find_plugins(path: Path) -> Generator[str, None, None]:
     """ return list of plugins in given path
     """
     LOGGER.debug("Looking for plugins in %s", path)
@@ -167,13 +169,11 @@ def find_plugins(path: Path) -> Generator[str,None,None]:
             maxver = cp['general'].get('qgisMaximumVersion')
 
         except Exception as exc:
-            LOGGER.error("Error reading plugin metadata '%s': %s",metadatafile,exc)
+            LOGGER.error("Error reading plugin metadata '%s': %s", metadatafile, exc)
             continue
 
-        if not checkQgisVersion(minver,maxver):
+        if not checkQgisVersion(minver, maxver):
             LOGGER.warning("Unsupported version for %s. Discarding", plugin)
             continue
 
         yield plugin.name
-
-
